@@ -69,18 +69,36 @@ def set_default_style(style='ticks', font='Noto Sans CJK JP', colors=None):
     return
 
 
-@contextmanager
-def timer(logger=None, format_str='{:.3f}[s]', prefix=None, suffix=None):
-    if prefix: format_str = str(prefix) + format_str
-    if suffix: format_str = format_str + str(suffix)
-    start = time()
-    yield
-    d = time() - start
-    out_str = format_str.format(d)
-    if logger:
-        logger.info(out_str)
-    else:
-        print(out_str)
+class Timer:
+    def __init__(self, logger=None, format_str='{:.3f}[s]', prefix=None, suffix=None, sep=' '):
+
+        if prefix: format_str = str(prefix) + sep + format_str
+        if suffix: format_str = format_str + sep + str(suffix)
+        self.format_str = format_str
+        self.logger = logger
+        self.start = None
+        self.end = None
+
+    @property
+    def duration(self):
+        if self.end is None:
+            return 0
+        return self.end - self.start
+
+    def __enter__(self):
+        self.start = time()
+
+    def __exit__(self, exc_type, exc_val, exc_tb):
+        self.end = time()
+        out_str = self.format_str.format(self.duration)
+        if self.logger:
+            self.logger.info(out_str)
+        else:
+            print(out_str)
+
+
+def timer(logger=None, format_str='{:.3f}[s]', prefix=None, suffix=None, sep=' '):
+    return Timer(logger=logger, format_str=format_str, prefix=prefix, suffix=suffix, sep=sep)
 
 
 def get_logger(name, log_level='DEBUG',
@@ -193,3 +211,22 @@ def sigmoid(x: np.ndarray, threshold=15.) -> np.ndarray:
     """
     x = np.clip(x, -threshold, threshold)
     return 1.0 / (1.0 + np.exp(-x))
+
+
+def param_to_name(params: dict, key_sep='_', key_value_sep='=') -> str:
+    """
+    dict を `key=value` で連結した string に変換します.
+
+    Args:
+        params:
+        key_sep:
+            key 同士を連結する際に使う文字列.
+        key_value_sep:
+            それぞれの key / value を連結するのに使う文字列.
+            `"="` が指定されると例えば { 'foo': 10 } は `"foo=10"` に変換されます.
+
+    Returns:
+        文字列化した dict
+    """
+    sorted_params = sorted(params.items())
+    return key_sep.join(map(lambda x: key_value_sep.join(map(str, x)), sorted_params))
